#!/bin/bash
#
# source: http://www.openprinting.org/download/foomatic-filters-4.0-20090302.tar.gz
#
# maintainer: gmg (g.monpontet@gmail.com)
#

#------------------Set Some Variables

soft="foomatic-filters"
softversion="4.0_20090302"
arch="i486"
cpu="i686"
packageversion="60.1"

buildir=$(pwd)
srcpkg="$buildir/foomatic-filters-4.0-20090302.tar.gz"
src="$buildir/foomatic-filters-4.0-20090302"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvzf $srcpkg
rm -f $dest.tgz
rm -rf $dest

#------------------Set correct permissions

cd $src

chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#------------------Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --mandir=/usr/man

make -j2
make install DESTDIR=$dest

mv $dest/etc/foomatic/filter.conf $dest/etc/foomatic/filter.conf.new
rm -f $dest/etc/foomatic/filter.conf.sample

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

find $dest/usr/man -type f -exec gzip -9 {} \;

#-------------------Prepare the documentation:

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a ChangeLog COPYING INSTALL README STANDARD* TODO USAGE $dest/usr/doc/$soft-$softversion

cat > $dest/install/doinst.sh << "EOF"
#!/bin/sh
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config etc/foomatic/filter.conf.new
EOF

#-----------------Make the slack-desc files

mkdir -p $dest/install
cat << EODESC >> $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

                |-----handy-ruler------------------------------------------------|
foomatic-filters: Foomatic-filters - The universal print filter "foomatic-rip"
foomatic-filters:
foomatic-filters: The universal print filter "foomatic-rip", used by spoolers to
foomatic-filters: convert PostScript job data into the printer's native format as
foomatic-filters: described by a printer/driver-specific PPD file
foomatic-filters:
foomatic-filters:
foomatic-filters:
foomatic-filters:
foomatic-filters:
foomatic-filters:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.tgz > $package.md5